{
Unit        : fshEnabgrp.pas
Description : TGroupBox derivative that recursivly enables/disables all
              children as well.
Version     : 1.03, 12 March 2000
Status      : Freeware
Copyright   : 2000, First Internet Software House
Contact   : http://www.fishouse.com (email: support@fishouse.com)

History:

  v1.03     : Rebranded for FISH
              12 March 2000

  v1.02     : First release
              31 August 1997

}

unit fshEnabgrp;

interface

uses
  StdCtrls, controls, classes;

type
  TfshEnableGroup = class(TGroupBox)
  private
    { Private declarations }
    FEnabled: boolean;
    FAffectLabels: boolean;
    procedure EnableGroup(cntrl: TWinControl; status: boolean);
  protected
    { Protected declarations }
    procedure SetEnabled(Value: boolean); override;
  public
    { Public declarations }
    constructor Create(AOwner: TComponent); override;
  published
    { Published declarations }
    property Enabled read FEnabled write SetEnabled default True; 
    property AffectLabels: boolean read FAffectlabels write FAffectLabels;
  end;

procedure Register;

implementation

procedure Register;
begin
  RegisterComponents('FISH', [TfshEnableGroup]);
end;

constructor TfshEnableGroup.Create(AOwner: TComponent);
begin
    inherited Create(AOwner);
    FEnabled := True;
    FAffectLabels := True;
end;

procedure TfshEnableGroup.SetEnabled(Value: boolean);
begin
    if FEnabled <> Value then
    begin
        FEnabled := Value;
        EnableGroup(self, Value);
    end;
    inherited;
end;

procedure TfshEnableGroup.EnableGroup(cntrl: TWinControl; status: boolean);
var Counter: integer;
begin
    with cntrl do
    begin
        for Counter := 0 to ControlCount-1 do
        begin
            if (Controls[counter] is TWinControl) then
            begin
                if TWinControl(controls[counter]).ControlCount > 0 then
                begin
                    EnableGroup(TWinControl(controls[counter]), status);
                end;
            end;
            if FAffectLabels then
            begin
                Controls[Counter].Enabled := status;
            end
            else
            begin
                if Controls[Counter].ClassType <> TLabel then
                    Controls[Counter].Enabled := status;
            end;
        end;
    end;
end;


end.
